Structures and Molecules
------------------------

This component can render the ``pymatgen`` objects ``Structure``,
``Molecule``, ``StructureGraph`` and ``MoleculeGraph``. See its
documentation `here. <../source/crystal_toolkit.components.structure>`_

Screenshot
~~~~~~~~~~

.. image:: ../images/structuremoleculecomponent.png
  :align: center
  :alt: Example of StructureMoleculeComponent

Example Usage
~~~~~~~~~~~~~

.. literalinclude:: ../../crystal_toolkit/apps/examples/structure.py

Callback Graph
~~~~~~~~~~~~~~

.. image:: ../images/structuremoleculecomponent_callbacks.png
  :align: center
  :alt: Example of StructureMoleculeComponent
